Crate sillad_conntest
sillad_
conntest
0.2.1
All Items
Crate Items
Structs
Crate
sillad_
conntest
Structs

Conn
Test
Dialer
Wraps an underlying dialer with a connection quality test.
Conn
Test
Listener
Wraps an underlying listener with a connection quality test.